@@ -4,13 +4,13 @@ package Chart::GGPlot;
 
 use Chart::GGPlot::Setup qw(:base :pdl);
 
-our $VERSION = '0.0001'; # VERSION
+our $VERSION = '0.0003'; # VERSION
 
 use Data::Munge qw(elem);
 use Data::Frame::Types qw(DataFrame);
 use Data::Frame::Util qw(guess_and_convert_to_pdl);
 use Module::Load;
-use Types::PDL qw(Piddle1D);
+use Types::PDL qw(Piddle1D PiddleFromAny);
 use Types::Standard qw(Maybe Str);
 
 use Chart::GGPlot::Plot;
@@ -47,16 +47,24 @@ sub ggplot {
 }
 
 
+# Do not check :$x, :$y's types here as we would like to allow coercion
+# from arrayref to piddle.
 fun qplot (
-    Piddle1D :$x, Piddle1D :$y, 
+    :$x, :$y, 
     :$facets = undef,
     Str :$geom = "auto",
     :$xlim = undef, :$ylim = undef,
     :$title = undef, :$xlab = 'x', :$ylab = 'y',
-#    : $asp     = undef,
     %rest
   ) {
+    # Can't do :$log in func params as it would conflict with $log
+    # from Log::Any.
     my $log_mode = $rest{log} // '';
+    state $supported_log_modes = ['', 'x', 'y', 'xy'];
+    unless ( elem( $log_mode, $supported_log_modes ) ) {
+        die "'log' shall be one of "
+          . join( ', ', map { qq("$_") } @$supported_log_modes );
+    }
 
     my $all_aesthetics = Chart::GGPlot::Aes->all_aesthetics;
 
@@ -126,7 +134,7 @@ Chart::GGPlot - ggplot2 port in Perl
 
 =head1 VERSION
 
-version 0.0001
+version 0.0003
 
 =head1 STATUS
 
@@ -168,14 +176,22 @@ library.
 Example exported image files:
 
 =for html <p float="left">
-<img src="https://raw.githubusercontent.com/stphnlyd/perl5-Chart-GGPlot/master/examples/position_stack_02_02.png" alt="proportional stacked bar" width="45%">
-<img src="https://raw.githubusercontent.com/stphnlyd/perl5-Chart-GGPlot/master/examples/geom_line_02_01.png" alt="line chart" width="45%">
-<img src="https://raw.githubusercontent.com/stphnlyd/perl5-Chart-GGPlot/master/examples/scale_viridis_02_01.png" alt="viridis color scale" width="45%">
-<img src="https://raw.githubusercontent.com/stphnlyd/perl5-Chart-GGPlot/master/examples/theme_01_06.png" alt="theme 'minimal'" width="45%">
+<img src="https://raw.githubusercontent.com/stphnlyd/perl5-Chart-GGPlot/master/examples/position_stack_02_02.png" alt="proportional stacked bar" width="40%">
+<img src="https://raw.githubusercontent.com/stphnlyd/perl5-Chart-GGPlot/master/examples/geom_line_02_01.png" alt="line chart" width="40%">
+<img src="https://raw.githubusercontent.com/stphnlyd/perl5-Chart-GGPlot/master/examples/geom_boxplot_01_02.png" alt="boxplot" width="40%">
+<img src="https://raw.githubusercontent.com/stphnlyd/perl5-Chart-GGPlot/master/examples/scale_viridis_02_01.png" alt="viridis color scale" width="40%">
+<img src="https://raw.githubusercontent.com/stphnlyd/perl5-Chart-GGPlot/master/examples/theme_01_06.png" alt="theme 'minimal'" width="40%">
 </p>
 
 See the C<examples> dir in the library's distribution for more examples.
 
+=head2 Document Conventions
+
+Function signatures in docs of this library follow the
+L<Function::Parameters> conventions, for example,
+
+    myfunc(Type1 $positional_parameter, Type2 :$named_parameter)
+
 =head1 FUNCTIONS
 
 =head2 ggplot
@@ -187,11 +203,59 @@ See L<Chart::GGPlot::Plot> for details.
 
 =head2 qplot
 
-    qplot(Piddle1D :$x, Piddle1D :$y, Str :$geom='auto',
+    qplot((Piddle1D|ArrayRef) :$x, (Piddle1D|ArrayRef) :$y,
+        Str :$geom='auto',
         :$xlim=undef, :$ylim=undef,
-        :$log='', :$title=undef, :$xlab='x', :$ylab='y',
+        Str :$log='',
+        Maybe[Str] :$title=undef, Str :$xlab='x', Str :$ylab='y',
         %rest)
 
+Arguments:
+
+=over 4
+
+=item *
+
+$x, $y
+
+Data. Supports either 1D piddles or arrayrefs. When arrayref is specified, it
+would be converted to either a numeric piddle or a PDL::SV piddle, guessing by
+its contents.
+
+=item *
+
+$geom
+
+Geom type. C<"auto"> is treated as C<'point'>.
+It would internally call a C<geom_${geom}> function.
+
+=item *
+
+$xlim, $ylim
+
+Axes limits.
+
+=item *
+
+$log
+
+Which axis use logarithmic scale?
+One of C<''>, C<'x'>, C<'y'>, C<'xy'>.
+
+=item *
+
+$title
+
+Plot title. Default is C<undef>, for no title.
+
+=item *
+
+$xlabel, $ylabel
+
+Axes labels.
+
+=back
+
 =head1 ENVIRONMENT VARIABLES
 
 =head2 CHART_GGPLOT_TRACE
