@@ -1,10 +1,10 @@
 package Chart::GGPlot::Backend::Plotly::Geom::Boxplot;
 
-# ABSTRACT: Chart::GGPlot's Plotly implementation for Geom::Boxplot
+# ABSTRACT: Chart::GGPlot's Plotly support for Geom::Boxplot
 
 use Chart::GGPlot::Class qw(:pdl);
 
-our $VERSION = '0.0010_01'; # TRIAL VERSION
+our $VERSION = '0.0003'; # VERSION
 
 with qw(Chart::GGPlot::Backend::Plotly::Geom);
 
@@ -16,17 +16,14 @@ use Chart::GGPlot::Backend::Plotly::Util qw(cex_to_px to_rgb pdl_to_plotly);
 use Chart::GGPlot::Geom::Boxplot;
 use Chart::GGPlot::Geom::Point;
 
-classmethod split_on () { [qw(color fill size)] }
-
-classmethod prepare_data ($data, $prestats_data, @rest) {
+classmethod to_basic ($data, $prestats_data, $layout, $params, $plot) {
     my @join_on_columns = qw(PANEL group);
-    my @prestats_data_columns = map { $prestats_data->at($_) } @join_on_columns;
 
     my $prestats_y = $prestats_data->at('y');
     my %prestats_y_grouped;    # PANEL;group => $y_data
     for my $ridx ( 0 .. $prestats_data->nrow - 1 ) {
         my @key_values =
-          map { $_->at($ridx) } @prestats_data_columns;
+          map { $prestats_data->at($_)->at($ridx) } @join_on_columns;
         my $k = join( $;, @key_values );
         $prestats_y_grouped{$k} //= [];
         push @{ $prestats_y_grouped{$k} }, $prestats_y->at($ridx);
@@ -43,7 +40,7 @@ classmethod prepare_data ($data, $prestats_data, @rest) {
     return $data;
 }
 
-classmethod to_traces ($df, $params, $plot) {
+classmethod to_trace ($df, $params, $plot) {
     load Chart::Plotly::Trace::Box;
     load Chart::Plotly::Trace::Box::Line;
     load Chart::Plotly::Trace::Box::Marker;
@@ -108,14 +105,13 @@ classmethod to_traces ($df, $params, $plot) {
         notched    => ( $params->at('notch') ? JSON::true : JSON::false ),
         notchwidth => $params->at('notchwidth'),
         hoverinfo  => ( $flip ? 'x' : 'y' ),
-        hoveron    => $class->hover_on,
 
         # plotly defaults to 'suspectedoutliers' to show outliers and
         # suspected in different styles.
         # we use 'outliers' here to align with ggplot2 behavior.
         boxpoints => 'outliers',
     );
-    return [ $class->_adjust_trace_for_flip($trace, $plot) ];
+    return $class->_adjust_trace_for_flip($trace, $plot);
 }
 
 __PACKAGE__->meta->make_immutable;
@@ -130,11 +126,11 @@ __END__
 
 =head1 NAME
 
-Chart::GGPlot::Backend::Plotly::Geom::Boxplot - Chart::GGPlot's Plotly implementation for Geom::Boxplot
+Chart::GGPlot::Backend::Plotly::Geom::Boxplot - Chart::GGPlot's Plotly support for Geom::Boxplot
 
 =head1 VERSION
 
-version 0.0010_01
+version 0.0003
 
 =head1 SEE ALSO
 
