@@ -4,27 +4,27 @@ package Chart::GGPlot::Backend::Plotly::Geom::Point;
 
 use Chart::GGPlot::Class;
 
-our $VERSION = '0.0001'; # VERSION
+our $VERSION = '0.0003'; # VERSION
 
 extends qw(Chart::GGPlot::Backend::Plotly::Geom::Path);
 
 use Module::Load;
 
-use Chart::GGPlot::Backend::Plotly::Util qw(cex_to_px to_rgb);
+use Chart::GGPlot::Backend::Plotly::Util qw(cex_to_px to_rgb pdl_to_plotly);
 use Chart::GGPlot::Util qw(ifelse);
 
 sub mode {
     return 'markers';
 }
 
-classmethod marker ($df, %rest) {
+classmethod marker ($df, $params, @rest) {
     my $color = to_rgb( $df->at('color') );
     my $fill =
       $df->exists('fill')
       ? ifelse( $df->at('fill')->isbad, $color, to_rgb( $df->at('fill') ) )
       : $color;
     my $size = cex_to_px( $df->at('size') );
-    $size = ifelse( $size < 2, 2, $size );
+    $size = ifelse( $size > 2, $size, 2 );
     my $opacity = $df->at('alpha')->setbadtoval(1);
     my $stroke  = cex_to_px( $df->at('stroke') );
 
@@ -38,16 +38,16 @@ classmethod marker ($df, %rest) {
     load $plotly_marker_class;
 
     return $plotly_marker_class->new(
-        color => $fill->unpdl,
-        size  => $size->unpdl,
+        color => pdl_to_plotly( $fill, true ),
+        size  => pdl_to_plotly( $size, true ),
         line  => {
-            color => $color->unpdl,
-            width => $stroke->unpdl,
+            color => pdl_to_plotly( $color,  true ),
+            width => pdl_to_plotly( $stroke, true ),
         },
 
         # TODO: support scatter symbol
         symbol  => [ (0) x $df->at('size')->length ],
-        opacity => $opacity->unpdl,
+        opacity => pdl_to_plotly( $opacity, true ),
     );
 }
 
@@ -67,7 +67,7 @@ Chart::GGPlot::Backend::Plotly::Geom::Point - Chart::GGPlot's Plotly support for
 
 =head1 VERSION
 
-version 0.0001
+version 0.0003
 
 =head1 SEE ALSO
 
