@@ -5,20 +5,18 @@ package Chart::GGPlot::Coord::Flip;
 use Chart::GGPlot::Class qw(:pdl);
 use namespace::autoclean;
 
-our $VERSION = '0.0010_01'; # TRIAL VERSION
+our $VERSION = '0.0003'; # VERSION
 
 extends qw(Chart::GGPlot::Coord::Cartesian); 
 
-use Chart::GGPlot::Util::Pod qw(unindent);
+my $coord_flip_pod = <<'=cut';
 
-my $coord_flip_pod = unindent(<<'EOT');
+    coord_flip(:$xlim=undef, :$ylim=undef, :$expand=true)
 
-        coord_flip(:$xlim=undef, :$ylim=undef, :$expand=true)
+Flip cartesian coordinates so that horizontal becomes vertical, and
+vertical becoms horizontal.
 
-    Flip cartesian coordinates so that horizontal becomes vertical, and
-    vertical becoms horizontal.
-
-EOT
+=cut
 
 my $coord_flip_code = sub {
     return __PACKAGE__->new(@_);
@@ -56,7 +54,7 @@ Chart::GGPlot::Coord::Flip - Cartesian coordinates with x and y flipped
 
 =head1 VERSION
 
-version 0.0010_01
+version 0.0003
 
 =head1 DESCRIPTION
 
