@@ -7,7 +7,7 @@ package Chart::GGPlot::Util::Scales;
 
 use Chart::GGPlot::Setup qw(:base :pdl);
 
-our $VERSION = '0.0001'; # VERSION
+our $VERSION = '0.0003'; # VERSION
 
 use Color::Brewer;
 use Convert::Color::LCh;
@@ -865,15 +865,20 @@ fun dollar ($p, :$accuracy=undef, :$scale=1,
     my $negative  = ( $p->isgood & ( $p < 0 ) );
 
     my $fmt = Number::Format->new(
-        -thousands_sep   => $big_mark,
-        -decimal_point   => $decimal_mark,
-        -int_curr_symbol => $prefix,
+        -thousands_sep     => $big_mark,
+        -mon_thousands_sep => $big_mark,
+        -decimal_point     => $decimal_mark,
+        -mon_decimal_point => $decimal_mark,
+        -int_curr_symbol   => $prefix,
         ( $negative_parens ? ( -n_sign_posn => 0 ) : () ),
 
-        # Number::Format defaulty uses locale's P/N_SEP_BY_SPACE.
-        # Here we force these values to 0 to be align with R's scale::dollar.
-        -p_sep_by_space  => 0,
-        -n_sep_by_space  => 0,
+        # Number::Format would use locale's settings like P/N_SEP_BY_SPACE.
+        # Here we force these values to align with R's scale::dollar to make
+        # the behavior simple.
+        -p_sep_by_space => 0,
+        -n_sep_by_space => 0,
+        -p_cs_precedes  => 1,
+        -n_cs_precedes  => 1,
     );
 
     no warnings 'numeric';
@@ -960,7 +965,7 @@ Chart::GGPlot::Util::Scales - R 'scales' package functions used by Chart::GGPlot
 
 =head1 VERSION
 
-version 0.0001
+version 0.0003
 
 =head1 FUNCTIONS
 
